@@ -1,5 +1,7 @@
 from configparser import ConfigParser
+from typing import Dict, Any, Union
 
+import h5py
 import numpy as np
 import warnings
 from collections import deque
@@ -551,18 +553,8 @@ class Fast5Read(AbstractFast5):
         if clear:
             for key in path_attr.keys():
                 del path_attr[key]
-        for key, value in attrs.items():
-            path_attr[key] = value
 
-    def _get_attributes(self, path):
-        """
-        :param path: filepath within fast5
-        :return: dictionary of attributes found at ``path``
-        :rtype dict
-        """
-        path_grp = self.handle[path]
-        path_attr = path_grp.attrs
-        return dict(path_attr)
+        copy_attributes(attrs, path_grp)
 
     def _add_attribute_tree(self, group, config):
         for folder, data in config.items():
@@ -577,3 +569,16 @@ class Fast5Read(AbstractFast5):
             attr = self.handle[path].attrs.items()
             data[folder] = {key: _clean(value) for key, value in attr}
         return data
+
+
+def copy_attributes(input_attrs: Union[h5py.AttributeManager, Dict[Any, Any]], output_group: h5py.Group):
+    """ Copy the members of a given h5py.AttributeManager into an output h5py.Group"""
+    if isinstance(input_attrs, h5py.AttributeManager):
+        # Ensure h5py data types (e.g. enumerations) are retained during copy
+        for name, data in input_attrs.items():
+            dtype = input_attrs.get_id(name).dtype
+            output_group.attrs.create(name=name, data=data, dtype=dtype)
+    else:
+        # Simple dictionary copy into the output group attributes
+        for name, data in input_attrs.items():
+            output_group.attrs[name] = data
\ No newline at end of file
